'\" Copyright (c) 1995 Sun Microsystems, Inc.
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\"
'\" SCCS: @(#) fconfigure.n 1.13 96/03/07 15:47:30
'\"
.so man.macros
.TH fconfigure n 7.5 Tcl "Tcl Built-In Commands"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
fconfigure \- Set and get options on a channel
.SH SYNOPSIS
.nf
\fBfconfigure \fIchannelId\fR
\fBfconfigure \fIchannelId\fR \fIname\fR
\fBfconfigure \fIchannelId\fR \fIname value \fR?\fIname value ...\fR?
.fi
.BE

.SH DESCRIPTION
.PP
The \fBfconfigure\fR command sets and retrieves options for channels.
\fIChannelId\fR identifies the channel for which to set or query an option.
If no \fIname\fR or \fIvalue\fR arguments are supplied, the command
returns a list containing alternating option names and values for the channel.
If \fIname\fR is supplied but no \fIvalue\fR then the command returns
the current value of the given option.
If one or more pairs of \fIname\fR and \fIvalue\fR are supplied, the
command sets each of the named options to the corresponding \fIvalue\fR;
in this case the return value is an empty string.
.PP
The options described below are supported for all channels. In addition,
each channel type may add options that only it supports.
.TP
\fB\-blocking\fR \fIboolean\fR
The \fB\-blocking\fR option determines whether I/O operations on the
channel can cause the process to block indefinitely.
The value of the option must be a proper boolean value.
Channels are normally in blocking mode;  if a channel is placed into
nonblocking mode it will affect the operation of the \fBgets\fR,
\fBread\fR, \fBputs\fR, \fBflush\fR, and \fBclose\fR commands;
see the documentation for those commands for details.
Setting \fBstdin\fR, \fBstdout\fR, or \fBstderr\fR into nonblocking mode
is disallowed because it could interfere with the operation of the
parent process.
For nonblocking mode to work correctly, the application must be
using the Tcl event loop (e.g. by calling \fBTcl_DoOneEvent\fR or
invoking the \fBvwait\fR command).
.TP
\fB\-buffering\fR \fInewValue\fR
If \fInewValue\fR is \fBfull\fR then the I/O system will buffer output
until its internal buffer is full or until the \fBflush\fR command is
invoked. If \fInewValue\fR is \fBline\fR, then the I/O system will
automatically flush output for the channel whenever a newline character
is output. If \fInewValue\fR is \fBnone\fR, the I/O system will flush
automatically after every output operation.
The default is for \fB\-buffering\fR to be set to \fBfull\fR except for
channels that connect to terminal-like devices; for these channels the
initial setting is \fBline\fR.
.TP
\fB\-buffersize\fR \fInewSize\fR
\fINewvalue\fR must be an integer; its value is used to set the size of
buffers, in bytes, subsequently allocated for this channel to store input
or output. \fINewvalue\fR must be between ten and one million, allowing
buffers of ten to one million bytes in size.
.TP
\fB\-translation\fR \fImode\fR
In Tcl scripts the end of a line is always represented using a
single newline character (\\n).
However, in actual files and devices the end of a line may be
represented differently on different platforms, or even for
different devices on the same platform.  For example, under UNIX
newlines are used in files, whereas carriage-return-linefeed
sequences are normally used in network connections.
The Tcl I/O system automatically translates between the newlines
used internally and whatever end-of-line characters are appropriate
for the underlying files and devices.
The \fB\-translation\fR option selects the end-of-line character(s)
to use on the file or device for a particular channel.
Note that if you want no translations at all applied to input and output on
a specific channel, you should set it to \fBlf\fR mode - see below.
The following values are currently supported:
.RS
.TP
\fBcr\fR
The end of a line in the underlying file or device is represented
by a single carriage return character.
During input commands such as \fBread\fR Tcl translates carriage returns
to newline characters, and during output commands such as \fBputs\fR
Tcl translates newline characters to carriage returns.
This mode is typically used on Macintosh platforms.
.TP
\fBcrlf\fR
The end of a line in the underlying file or device is represented
by a carriage return character followed by a linefeed character.
During input commands such as \fBread\fR Tcl translates
carriage-return-linefeed sequences to newlines, and during output
commands such as \fBputs\fR Tcl translates newline characters to
carriage-return-linefeed sequences.
This mode is typically used on Windows platforms and for network
connections.
.TP
\fBlf\fR
The end of a line in the underlying file or device is represented
by a single newline (linefeed) character.
In this mode no translations occur during either intput or output.
This mode is typically used on UNIX platforms.
.TP
\fIbinary\fR
This is a synonym for \fIlf\fR mode.
.TP
\fBplatform\fR
Tcl chooses a translation mode for the channel according to the platform
on which the application is executing; for sockets on all platforms Tcl
chooses \fBcrlf\fR, for all Unix flavors, it chooses \fBlf\fR, for the
Macintosh platform it chooses \fBcr\fR and for the various flavors of
Windows it chooses \fBcrlf\fR.
.TP
\fBauto\fR
In this mode Tcl sets the translation mode based on the first
valid end-of-line sequence it sees during input on the channel.
If output is generated for the channel before an end-of-line
sequence has appeared on input, then Tcl uses \fBplatform\fR mode
for the channel.
The default setting for \fB\-translation\fR is \fBauto\fR.
.RE
.PP

.SH "SEE ALSO"
close(n), flush(n), gets(n), puts(n), read(n)

.SH KEYWORDS
blocking, buffering, carriage return, end of line, flushing, linemode,
newline, nonblocking, platform, translation
