'\"
'\" Copyright (c) 1995 Sun Microsystems, Inc.
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
'\" SCCS: @(#) filename.n 1.5 96/02/15 20:03:07
'\" 
.so man.macros
.TH filename n 7.5 Tcl "Tcl Built-In Commands"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
filename \- File name conventions supported by Tcl commands
.BE
.SH INTRODUCTION
.PP
All Tcl commands and C procedures that take file names as arguments
allow the file names to be in one of two forms: \fInative\fR or
\fInetwork\fR.  Each platform that Tcl supports defines a native file
naming convention that should be familiar to users of that platform.
In addition, Tcl defines a file naming convention that can be used by
scripts in a platform independent fashion.  Since the characters used
to separate parts of a path name are different on different platforms,
the network file naming convention should be used by scripts that wish
to be portable.  By choosing file names from a subset of those allowed
on the various platforms and by using network style paths, a Tcl
script can access files without needing to know how native paths are
constructed.

.SH NATIVE NAMES
.PP
The rules for native names depend on the current value of the Tcl
array element \fBtcl_platform(platform)\fR:
.TP
\fBmac\fR
On Apple Macintosh platforms, Tcl uses path names where the components are
separated by colons.  Paths may be relative or absolute, and file names may
contain any character other than colon.  A leading colon causes the rest of
the path to be interpreted relative to the current directory.  If path
contains a colon that is not at the beginning, then the path is interpreted
as an absolute path.  A trailing colon indicates a folder.  If there are no
colons, then the name is interpreted relative to the current folder.
Sequences of two or more colons anywhere in the path are used to construct
relative paths where \fB::\fR refers to the parent of the current
directory, \fB:::\fR refers to the parent of the parent, and so forth.  The
following examples illustrate various forms of path names:
.RS
.TP 15
\fB:\fR
Relative path to the current folder.
.TP 15
\fBMyFile\fR
Relative path to a file named \fBMyFile\fR in the current folder.
.TP 15
\fBMyDisk:MyFile\fR
Absolute path to a file named \fBMyFile\fR on the device named \fBMyDisk\fR.
.TP 15
\fB:MyDir:MyFile\fR
Relative path to a file name \fBMyFile\fR in a folder named
\fBMyDir\fR in the current folder.
.TP 15
\fB::MyFile\fR
Relative path to a file named \fBMyFile\fR in the folder above the
current folder.
.TP 15
\fB:::MyFile\fR
Relative path to a file named \fBMyFile\fR in the folder two levels above the
current folder. 
.RE
.TP
\fBunix\fR
On Unix-like platforms, Tcl uses path names where the components are
separated by slashes.  Path names may be relative or absolute, and
file names may contain any character other than slash.  The file names
\fB\&.\fR and \fB\&..\fR are special and refer to the current directory
and the parent of the current directory respectively.  Multiple
adjacent slash characters are interpreted as a single separator.
The following examples illustrate various forms of path names:
.RS
.TP 15
\fB/\fR
Absolute path to the root directory.
.TP 15
\fB/etc/passwd\fR
Absolute path to the file named \fBpasswd\fR in the directory
\fBetc\fR in the root directory.
.TP 15
\fB\&.\fR
Relative path to the current directory.
.TP 15
\fBfoo\fR
Relative path to the file \fBfoo\fR in the current directory.
.TP 15
\fBfoo/bar\fR
Relative path to the file \fBbar\fR in the directory \fBfoo\fR in the
current directory.
.TP 15
\fB\&../foo\fR
Relative path to the file \fBfoo\fR in the directory above the current
directory. 
.RE
.TP
\fBwindows\fR
On Microsoft Windows platforms, Tcl supports both drive-relative and UNC
style names.  Both \fB/\fR and \fB\e\fR may be used as directory separators
in either type of name.  Drive-relative names consist of an optional drive
specifier followed by an absolute or relative path.  UNC paths follow the
general form \fB\e\eservername\esharename\epath\efile\fR.  In both forms,
the file names \fB.\fR and \fB..\fR are special and refer to the current
directory and the parent of the current directory respectively.  The
following examples illustrate various forms of path names:
.RS
.TP 15
\fB\&\e\eHost\eshare/file\fR
Absolute UNC path to a file called \fBfile\fR in the root directory of
the export point \fBshare\fR on the host \fBHost\fR.
.TP 15
\fBc:foo\fR
Relative path to a file \fBfoo\fR in the current directory on drive
\fBc\fR.
.TP 15
\fBc:/foo\fR
Absolute path to a file \fBfoo\fR in the root directory of drive
\fBc\fR.
.TP 15
\fBfoo\ebar\fR
Relative path to a file \fBbar\fR in the \fBfoo\fR directory in the current
directory on the current volume.
.TP 15
\fB\&\efoo\fR
Absolute path to a file \fBfoo\fR in the root directory of the current volume.
.RE

.SH NETWORK NAMES
.PP
Network names follow the general form \fB//root/export/path\fR...\fB/name\fR.
The \fB//root/export/\fR component refers to a network host and export
directory, and is optional. The leading slash on the path component may also
be omitted, in which case the path is interpreted relative to the current
directory.  In addition, network paths must conform to the following rules:
.IP [1]
\fB//\fR may only appear at the beginning of a path.
.IP [2]
\fB/\fR is used to separate components in the path.
.IP [3]
\fB\e\fR must be used to quote characters in the set \fB:/\e\fR that
are used in the middle of a path component.
.IP [4]
The characters \fB:\fR and \fB\e\fR may not appear unquoted.
.IP [5]
The first character of a path cannot be a "\fB\e\fR".  If a path begins
with a character that must be quoted, then "\fB./\fR" must be
prepended to the path.
.PP
All native paths have an equivalent network representation.  The
mapping from native to network paths involves converting native path
separators into forward slashes, quoting embedded slash, backslash,
and colon characters, and handling a few special cases:
.IP
Windows drive-relative paths are represented as \fB//?/\fIx\fB\e:./\fIpath\fR for
relative paths, and \fB//?/\fIx\fB\e:/\fIpath\fR for absolute paths, where
\fIx\fR is a drive letter.  For example, \fBc:foo\fR would be
represented as \fB//?/c\e:./foo\fR.
.IP
Unix paths containing multiple adjacent slashes are be converted to an
equivalent path containing no adjacent slashes.
.PP
Not all network paths have an equivalent native representation.  In
cases where no mapping is possible, Tcl commands will return an error.
For example, \fB//host/share\fR will cause an error on Mac and Unix
file systems.  In cases where a path is ambiguous and could be
interpreted as either a native or a network path, Tcl commands will
assume a network interpretation.  For example, the file \fBfoo/bar\fR
could refer to a network file named \fBbar\fR in the directory
\fBfoo\fR, or it could refer to a Macintosh file named \fBfoo/bar\fR.
Tcl will choose the network name interpretation.  In order to force
the Macintosh interpretation, a script could use \fB:foo/bar\fR
instead.

.SH TILDE SUBSTITUTION
.PP
In addition to the file name rules described above, Tcl also supports
\fIcsh\fR-style tilde substitution.  If a file name starts with a
tilde, then the file name will be interpreted as if the first element
is replaced with the location of the home directory for the given
user.  If the tilde is followed immediately by a separator, then the
\fB$HOME\fR environment variable is substituted.  Otherwise the
characters between the tilde and the next separator are taken as a
user name, which is used to retrieve the user's home directory for
substitution.

.SH PORTABILITY ISSUES
.PP
Not all file systems are case sensitive, so scripts should avoid code
that depends on the case of characters in a file name.  In addition,
the character sets allowed on different devices may differ, so scripts
should choose file names that do not contain special characters like:
\fB<>:"/\e|\fR.  The safest approach is to use network names to
construct paths.
.PP
The Macintosh and Windows platforms do not support tilde substitution
when a user name follows the tilde.  On these platforms, attempts to
use a tilde followed by a user name will generate an error.  File
names that have a tilde without a user name will be substituted using
the \fB$HOME\fR environment variable, just like for Unix.

.SH KEYWORDS
file name, network name, native name
